Fixit: advanced linting framework
=================================

.. include:: ../README.rst
    :start-line: 4


.. toctree::
    :hidden:
    :maxdepth: 1

    why

.. toctree::
    :hidden:
    :maxdepth: 2

    guide
    api

.. toctree::
    :hidden:
    :maxdepth: 1

    changelog
    contributing
    code-of-conduct
